"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const i18n = require("i18n");
const path = require("path");
const index_1 = require("../index");
/**
 * Translations and such.
 */
class I18N extends index_1.Initializer {
    constructor() {
        super();
        this.name = "i18n";
        this.loadPriority = 10;
    }
    async initialize() {
        const options = index_1.api.config.i18n;
        options.directory = path.normalize(index_1.api.config.general.paths.locale[0]);
        i18n.configure(options);
        i18n.setLocale(index_1.api.config.i18n.defaultLocale);
        index_1.api.i18n = Object.assign({
            // simplistic determination of locale for connection
            determineConnectionLocale: (connection) => {
                // perhpas you want to look at the `accept-language` headers from a web requests
                // perhaps your API can use a certain cookie or URL to determine locale
                return index_1.api.config.i18n.defaultLocale;
            },
            invokeConnectionLocale: (connection) => {
                const cmdParts = index_1.api.config.i18n.determineConnectionLocale.split(".");
                const cmd = cmdParts.shift();
                if (cmd !== "api") {
                    throw new Error("cannot operate on a method outside of the api object");
                }
                const method = index_1.api.utils.dotProp.get(index_1.api, cmdParts.join("."));
                const locale = method(connection);
                index_1.api.i18n.setLocale(connection, locale);
            },
            /**
             * Return a translated string.
             */
            localize: (message, options = index_1.api.i18n) => {
                const messageArray = Array.isArray(message) ? message : [message];
                return index_1.api.i18n.__.apply(options, messageArray);
            }
        }, i18n);
    }
}
exports.I18N = I18N;
