"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const optimist_1 = require("optimist");
const cluster = require("cluster");
const index_1 = require("../index");
/**
 * I build this server's ID.
 */
class ID extends index_1.Initializer {
    constructor() {
        super();
        this.name = "id";
        this.loadPriority = 10;
        this.startPriority = 2;
    }
    async initialize() {
        if (optimist_1.argv.title) {
            index_1.api.id = optimist_1.argv.title;
        }
        else if (process.env.ACTIONHERO_TITLE) {
            index_1.api.id = process.env.ACTIONHERO_TITLE;
        }
        else if (!index_1.api.config.general.id) {
            let externalIP = index_1.api.utils.getExternalIPAddress();
            if (!externalIP) {
                const message = " * Error fetching this hosts external IP address; setting id base to 'actionhero'";
                try {
                    index_1.api.log(message, "crit");
                }
                catch (e) {
                    console.log(message);
                }
                externalIP = "actionhero";
            }
            index_1.api.id = externalIP;
            if (cluster.isWorker) {
                index_1.api.id += ":" + process.pid;
            }
        }
        else {
            index_1.api.id = index_1.api.config.general.id;
        }
    }
    async start() {
        index_1.api.log(`server ID: ${index_1.api.id}`, "notice");
    }
}
exports.ID = ID;
