"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const cluster = require("cluster");
const index_1 = require("../index");
/**
 * Pid and Pidfile.
 */
class Pids extends index_1.Initializer {
    constructor() {
        super();
        this.name = "pids";
        this.loadPriority = 50;
        this.startPriority = 1;
    }
    async initialize() {
        index_1.api.pids = {};
        index_1.api.pids.pid = process.pid;
        index_1.api.pids.path = index_1.api.config.general.paths.pid[0]; // it would be silly to have more than one pid
        index_1.api.pids.sanitizeId = function () {
            let pidfile = String(index_1.api.id).trim();
            pidfile = pidfile.replace(new RegExp(":", "g"), "-");
            pidfile = pidfile.replace(new RegExp(" ", "g"), "_");
            return pidfile;
        };
        if (cluster.isMaster) {
            index_1.api.pids.title = "actionhero-" + index_1.api.pids.sanitizeId();
        }
        else {
            index_1.api.pids.title = index_1.api.pids.sanitizeId();
        }
        try {
            fs.mkdirSync(index_1.api.pids.path);
        }
        catch (e) { }
        index_1.api.pids.writePidFile = () => {
            fs.writeFileSync(index_1.api.pids.path + "/" + index_1.api.pids.title, index_1.api.pids.pid.toString(), "ascii");
        };
        index_1.api.pids.clearPidFile = () => {
            try {
                fs.unlinkSync(index_1.api.pids.path + "/" + index_1.api.pids.title);
            }
            catch (error) {
                index_1.api.log("Unable to remove pidfile", "error", error);
            }
        };
    }
    async start() {
        index_1.api.pids.writePidFile();
        index_1.api.log(`pid: ${process.pid}`, "notice");
    }
}
exports.Pids = Pids;
