import { Initializer } from "../index";
/**
 * An exmaple middleware
 * ```js
 * const middleware = {
 *   name: 'timer',
 *   global: true,
 *   priority: 90,
 *   preProcessor: async function () {
 *     const worker = this.worker
 *     worker.startTime = process.hrtime()
 *   },
 *   postProcessor: async function () {
 *     const worker = this.worker
 *     const elapsed = process.hrtime(worker.startTime)
 *     const seconds = elapsed[0]
 *     const millis = elapsed[1] / 1000000
 *     api.log(worker.job.class + ' done in ' + seconds + ' s and ' + millis + ' ms.', 'info')
 *   },
 *   preEnqueue: async function () {
 *     const arg = this.args[0]
 *     return (arg === 'ok') // returing `false` will prevent the task from enqueing
 *   },
 *   postEnqueue: async function () {
 *     api.log("Task successfully enqueued!")
 *   }
 * }
 * api.tasks.addMiddleware(middleware)
```
 */
export interface TaskMiddleware {
    /**Unique name for the middleware. */
    name: string;
    /**Is this middleware applied to all tasks? */
    global: boolean;
    /**Module load order. Defaults to `api.config.general.defaultMiddlewarePriority`. */
    priority?: number;
    /**Called berore the task runs.  Has access to all params, before sanitizartion.  Can modify the data object for use in tasks. */
    preProcessor?: Function;
    /**Called after the task runs.*/
    postProcessor?: Function;
    /**Called before a task using this middleware is enqueud. */
    preEnqueue?: Function;
    /**Called after a task using this middleware is enqueud. */
    postEnqueue?: Function;
}
/**
 * Tools for enquing and inspecting the task sytem (delayed jobs).
 */
export declare class Tasks extends Initializer {
    constructor();
    initialize(): Promise<void>;
    start(): Promise<void>;
}
